@@ -4,8 +4,17 @@
 import ctypes
 
 
+old_find_library = ctypes.util.find_library
+
+
+def new_find_library(name):
+    if 'portaudio' in name.lower():
+        return NotImplemented
+    return old_find_library(name)
+
+
 # Monkey-patch ctypes to disable searching for PortAudio
-ctypes.util.find_library = lambda _: NotImplemented
+ctypes.util.find_library = new_find_library
 
 
 class ffi(object):
